summaryrefslogtreecommitdiff
path: root/zwgc/mux.c
diff options
context:
space:
mode:
authorGravatar John Kohl <jtkohl@mit.edu>1989-11-09 07:27:59 +0000
committerGravatar John Kohl <jtkohl@mit.edu>1989-11-09 07:27:59 +0000
commit754d64396c8f2f7752604a73d46e928460b064d9 (patch)
tree611c6affab744fcb4e21db88f0b5c86eecf7024c /zwgc/mux.c
parentcfa453758938ef83bce5d63a96a887259d8b11a5 (diff)
change to use "pointer" type for ease of porting to compilers which
barf on void *
Diffstat (limited to 'zwgc/mux.c')
-rw-r--r--zwgc/mux.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/zwgc/mux.c b/zwgc/mux.c
index f2b3a6c..37c363c 100644
--- a/zwgc/mux.c
+++ b/zwgc/mux.c
@@ -13,7 +13,7 @@
*/
#if (!defined(lint) && !defined(SABER))
-static char rcsid_mux_c[] = "$Header$";
+static char rcsid_mux_c[] = "$Id$";
#endif
#include <zephyr/mit-copyright.h>
@@ -31,6 +31,7 @@ static char rcsid_mux_c[] = "$Header$";
#include "mux.h"
#include "error.h"
#include "zwgc.h"
+#include "pointer.h"
/*
* mux_end_loop_p - Setting this to true during a mux_loop causes the mux_loop
@@ -53,7 +54,7 @@ static int max_source = -1;
static fd_set input_sources;
static void (*input_handler[MAX_SOURCES])();
-static void *input_handler_arg[MAX_SOURCES];
+static pointer input_handler_arg[MAX_SOURCES];
/*
* void mux_init()
@@ -73,7 +74,7 @@ void mux_init()
}
/*
* void mux_add_input_source(int descriptior; void (*handler)(); void *arg)
* Requires: 0<=descriptor<MAX_SOURCES, mux_init has been called
* Modifies: Removes the previous input handler if any for descriptor
* Effects: Registers handler as the input handler for file descriptor
@@ -85,7 +86,7 @@ void mux_init()
void mux_add_input_source(descriptor, handler, arg)
int descriptor;
void (*handler)();
- void *arg;
+ pointer arg;
{
#ifdef DEBUG
if(descriptor < 0 || descriptor >= MAX_SOURCES)
@@ -106,10 +107,10 @@ void mux_add_input_source(descriptor, handler, arg)
* mux_end_loop_p false to start). Whenever input is
* available on an input source which has a registered
* handler (see mux_add_input_source), that handler is
- * called with its argument. It is guarenteed that if
+ * called with its argument. It is guaranteed that if
* input is available on a source, its respective input
* handler, if any, will eventually be called. No other
- * ordering guarentees are made. When some signal handler
+ * ordering guarantees are made. When some signal handler
* or input handler eventually sets mux_end_loop_p to
* true, we return.
*/
@@ -73,7 +74,7 @@ void mux_init()
}
/*
- * void mux_add_input_source(int descriptior; void (*handler)(); void *arg)
+ * void mux_add_input_source(int descriptor; void (*handler)(); pointer arg)
* Requires: 0<=descriptor<MAX_SOURCES, mux_init has been called
* Modifies: Removes the previous input handler if any for descriptor